<?php
header('Content-Type: application/json; charset=UTF-8');
header("Access-Control-Allow-Origin: *");
header('Access-Control-Allow-Methods: POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With');

include "config.php";
date_default_timezone_set("Asia/Kolkata");

// Check if it's a preflight request and respond with 200 OK
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Fetch user data along with count of product IDs (pids) from the cart where products are active
$user_sql = "SELECT 
                u.id AS user_id, 
                u.fireToken, 
                u.mandal_id, 
                u.members, 
                u.name, 
                u.email, 
                u.phone, 
                u.address, 
                u.engagement, 
                u.anniversary, 
                u.dob, 
                u.c_name, 
                u.c_card, 
                u.c_mobile, 
                u.g_percent, 
                u.g_date, 
                u.token, 
                u.auth, 
                u.timestamp, 
                u.date AS user_date,
                COUNT(c.pid) AS pid_count
            FROM users u
            JOIN cart c ON u.id = c.uid
            JOIN products p ON p.id = c.pid
            WHERE p.active = 0
            GROUP BY u.id";

$user_result = mysqli_query($conn, $user_sql);
$users = [];

if ($user_result) {
    while ($user = mysqli_fetch_assoc($user_result)) {
        $users[] = $user;
    }
} else {
    echo json_encode(["message" => "Failed to fetch user data.", "error" => mysqli_error($conn)]);
    exit;
}

// Fetch product details for product IDs in the cart for each user
foreach ($users as &$user) {
    $user_id = $user['user_id'];

    $product_sql = "SELECT 
                        p.id, 
                        p.name, 
                        p.active, 
                        p.stock, 
                        p.code, 
                        p.category, 
                        p.img, 
                        p.img1, 
                        p.img2, 
                        p.net, 
                        p.gross, 
                        p.diamond, 
                        p.dprice, 
                        p.gender, 
                        p.description, 
                        p.d_gm, 
                        p.d_karat, 
                        p.dis_price, 
                        p.price, 
                        p.type, 
                        c.date AS cdate,
                        p.date AS product_date
                    FROM products p
                    JOIN cart c ON p.id = c.pid
                    WHERE c.uid = $user_id AND p.active = 0";

    $product_result = mysqli_query($conn, $product_sql);
    $products = [];

    if ($product_result) {
        while ($product = mysqli_fetch_assoc($product_result)) {
            $products[] = $product;
        }
    } else {
        echo json_encode(["message" => "Failed to fetch product data for user ID $user_id.", "error" => mysqli_error($conn)]);
        exit;
    }

    $user['products'] = $products;
}

// Return the $users array as JSON
echo json_encode(["message" => "radha", "result" => $users]);
?>
