<?php
// Include necessary files
include "utils/ResponseWare.php";
include "utils/DecryptWare.php";
include "database/db.php";
include "utils/AuthWare.php"; 

date_default_timezone_set("Asia/Kolkata");

$limit = 5;
$page = isset($req['page']) ? intval($req['page']) : 1;
$offset = ($page - 1) * $limit;

$category = isset($req['category']) ? $req['category'] : null;
$collection = isset($req['collection']) ? $req['collection'] : null;
$occassion = isset($req['occassion']) ? $req['occassion'] : null;
$material = isset($req['material']) ? $req['material'] : null;
$price = isset($req['price']) ? $req['price'] : null;
$gender = isset($req['gender']) ? $req['gender'] : null;
$sort = isset($req['sort']) ? $req['sort'] : null;
$uid = isset($req['uid']) ? $req['uid'] : null; 

// Convert input strings to arrays
$categoryArray = convertStringToArray($category);
$collectionArray = convertStringToArray($collection);
$occassionArray = convertStringToArray($occassion);
$materialArray = convertStringToArray($material);
$priceArray = convertStringToArray($price);
$genderArray = convertStringToArray($gender);

// Initialize data array and filter array
$data = [];
$filter = [];

// Initialize error variable
$error = '';

// Build query to fetch category and collection names
$query12 = "
    SELECT name AS category_name FROM category WHERE category.id IN ('" . implode("','", $categoryArray) . "')
    UNION
    SELECT name AS category_name FROM collection WHERE collection.id IN ('" . implode("','", $collectionArray) . "')
    UNION
    SELECT name AS category_name FROM occassion WHERE occassion.id IN ('" . implode("','", $occassionArray) . "')
    UNION
    SELECT name AS category_name FROM material WHERE material.id IN ('" . implode("','", $materialArray) . "')
";

$result12 = mysqli_query($conn, $query12);

// Check for query execution error
if (!$result12) {
    $error = "Error executing query: " . mysqli_error($conn);
} else {
    // Fetch results and add to $filter array
    while ($row12 = mysqli_fetch_assoc($result12)) {
        $filter[] = ["filter" => $row12['category_name']];
    }
}

// Build query to fetch products
$query = "SELECT 
            p.*, 
            m.name AS material_name,
            CASE
                WHEN p.price = 0 THEN (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat) + ((p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat)) * 0.03))
                ELSE (p.price + (p.price * 0.03))
            END AS calculated_price,
            CASE
                WHEN p.price = 0 THEN (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat))
                ELSE (p.dis_price + (p.dis_price * 0.03))
            END AS calculated_discount,
            (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat)) * 0.03 AS gst,
            (p.net * m.price / 2) AS mm,
            (m.price * p.d_karat) AS dtotal
          FROM 
            products AS p
          INNER JOIN 
            material AS m ON p.type = m.id
          WHERE 
            p.active = 0 AND p.stock > 0";

// Add conditions based on user input
if (!empty($categoryArray)) {
    $query .= " AND p.category IN ('" . implode("','", $categoryArray) . "')";
}

if (!empty($materialArray)) {
    $query .= " AND p.type IN ('" . implode("','", $materialArray) . "')";
}

if (!empty($genderArray)) {
    $tempGenderArray = array_merge($genderArray, ['Unisex']);
    $query .= " AND p.gender IN ('" . implode("','", $tempGenderArray) . "')";
}

if (!empty($collectionArray)) {
    $collectionConditions = [];
    foreach ($collectionArray as $collectionId) {
        $collectionConditions[] = "p.id IN (SELECT proid FROM collectioncon WHERE collid = '$collectionId')";
    }
    $query .= " AND (" . implode(" OR ", $collectionConditions) . ")";
}

if (!empty($priceArray)) {
    $priceConditions = [];
    foreach ($priceArray as $range) {
        list($min, $max) = explode('-', $range);
        $min = floatval(mysqli_real_escape_string($conn, $min));
        $max = floatval(mysqli_real_escape_string($conn, $max));
        $priceConditions[] = "(
            CASE
                WHEN p.price = 0 THEN (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat) + ((p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat)) * 0.03))
                ELSE (p.price + (p.price * 0.03))
            END 
            <= $range)";
    }
    if (!empty($priceConditions)) {
        $query .= " AND (" . implode(" OR ", $priceConditions) . ")";
    }
}

foreach ($priceArray as $priceItem) {
    $filter[] = array("filter" => "Under ".$priceItem);
}

foreach ($genderArray as $genderItem) {
    $filter[] = array("filter" => $genderItem);
}

foreach ($materialArray as $materialItem) {
    $filter[] = array("filter" => $materialItem);
}

if (!empty($occassionArray)) {
    $occassionConditions = [];
    foreach ($occassionArray as $occassionId) {
        $occassionConditions[] = "p.id IN (SELECT proid FROM occassioncon WHERE occid = '$occassionId')";
    }
    $query .= " AND (" . implode(" OR ", $occassionConditions) . ")";
}

// Add sorting condition
if ($sort == "latest") {
    $query .= " ORDER BY p.id DESC";
} elseif ($sort == "abc") {
    $query .= " ORDER BY p.name ASC";
} elseif ($sort == "xyz") {
    $query .= " ORDER BY p.name DESC";
} elseif ($sort == "lowhigh") {
    $query .= " ORDER BY 
        CASE
            WHEN p.price = 0 THEN (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat) + ((p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat)) * 0.03))
            ELSE (p.price + (p.price * 0.03))
        END ASC";
} elseif ($sort == "highlow") {
    $query .= " ORDER BY 
        CASE
            WHEN p.price = 0 THEN (p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat) + ((p.net * m.price + (p.net * m.price / 2) + (m.price * p.d_karat)) * 0.03))
            ELSE (p.price + (p.price * 0.03))
        END DESC";
} else {
    $query .= " ORDER BY p.id DESC";
}

$query .= " LIMIT $limit OFFSET $offset";

// Execute the SQL query
$result = mysqli_query($conn, $query);

// Check for errors
if (!$result) {
    $error = "Error executing query: " . mysqli_error($conn);
} else {
    // Fetch results
    while ($row = mysqli_fetch_assoc($result)) {
        $productId = $row['id'];
        $net = $row['net'];
        $gross = $row['gross'];
        $dgm = $row['d_gm'];
        $dkarat = $row['d_karat'];
        $material = $row['type'];
        $mQuery = "SELECT * FROM material WHERE id='$material'";
        $mResult = mysqli_query($conn, $mQuery);
        $mrow = mysqli_fetch_array($mResult);
        $mname = $mrow['name'];
        $mprice = $mrow['price'];
        $dprice = $row['dprice'];
        $dtotal = round($dprice);

        if ($material == 3) {
            if ($net > 2.000 && $net < 5.000) {
                $making = 600; 
            } elseif ($net > 5.000 && $net < 10.000) {
                $making = 700;
            } elseif ($net > 10.000 && $net < 15.000) {
                $making = 800;
            } elseif ($net > 15.000 && $net < 20.000) {
                $making = $net * 60;
            } elseif ($net > 20.000 && $net < 25.000) {
                $making = $net * 50;
            } elseif ($net > 25.000) {
                $making = $net * 40;
            }
            $mm = $making / 2;
            $ggg = $net * $mprice + $mm + $dtotal;
            $gst = round($ggg * 0.03);
            $price = round($net * $mprice + $mm + $gst + $dtotal);
            $discount = round($net * $mprice + $making + $gst + $dtotal);
        } elseif ($material == 8) {
            if ($net > 0.000 && $net < 0.500) {
                $making = $net * 1400; 
            } elseif ($net > 0.510 && $net < 0.800) {
                $making = $net * 1650;
            } elseif ($net > 0.810 && $net < 1.000) {
                $making = $net * 2050;
            } elseif ($net > 1.010 && $net < 1.400) {
                $making = $net * 2350;
            } elseif ($net > 1.410 && $net < 1.900) {
                $making = $net * 2600;
            } elseif ($net > 1.910 && $net < 2.200) {
                $making = $net * 2850;
            } else {
                $making = $net * 1500;
            }
            $mm = $making / 2;
            $ggg = $net * $mprice + $mm + $dtotal;
            $gst = round($ggg * 0.03);
            $price = round($net * $mprice + $mm + $gst + $dtotal);
            $discount = round($net * $mprice + $making + $gst + $dtotal);
        } else {
            $p = $row['price'];
            $fgst = $row['price'] * 0.03;
            $pp = $row['price'] + $fgst;
            $price = $pp;
            $discount = $row['dis_price'] + $row['dis_price'] * 0.03;
        }

        $cartCheckQuery = "SELECT * FROM cart WHERE pid='$productId' AND uid='$uid'";
        $cartCheckResult = mysqli_query($conn, $cartCheckQuery);
        $in_cart = ($cartCheckResult && mysqli_num_rows($cartCheckResult) > 0) ? true : false;

        $wishlistCheckQuery = "SELECT * FROM wishlist WHERE pid='$productId' AND uid='$uid'";
        $wishlistCheckResult = mysqli_query($conn, $wishlistCheckQuery);
        $in_wishlist = ($wishlistCheckResult && mysqli_num_rows($wishlistCheckResult) > 0) ? true : false;

        $data[] = array(
            "id" => $row['id'],
            "img" => $imgpath."/Products/" . $row['img'],
            "price" => round($price),
            "name" => $row['name'],
            "discount" => round($discount),
            "category" => $row['category'],
            "desc" => $row['description'],
            "total" => $row['price'],
            "img1" => $imgpath."/Products/" . $row['img1'],
            "img2" => $imgpath."/Products/" . $row['img2'],
            "cart" => $in_cart,
            "wishlist" => $in_wishlist,
        );
    }
    mysqli_free_result($result);
}

// Check for errors and return JSON response
if ($error) {
    echo json_encode(["message" => $error]);
} else if (count($data) > 0) {
    echo json_encode(["result" => $data, "filter" => $filter, "message" => "radha"]);
} else {
    echo json_encode(["message" => "No product found."]);
}

// Function to convert string to array
function convertStringToArray($inputString) {
    $cleanedString = str_replace(["[", "]", "'", " "], "", $inputString);
    return array_filter(explode(",", $cleanedString));
}
?>
